==> taler-wallet-v0.9.4a.tar.gz: taler-wallet-v0.9.4a/packages/web-util/src/forms/InputChoiceHorizontal.stories.tsx <==
/*
 This file is part of GNU Taler
 (C) 2022 Taler Systems S.A.

 GNU Taler is free software; you can redistribute it and/or modify it under the
 terms of the GNU General Public License as published by the Free Software
 Foundation; either version 3, or (at your option) any later version.

 GNU Taler is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

 You should have received a copy of the GNU General Public License along with
 GNU Taler; see the file COPYING.  If not, see <http://www.gnu.org/licenses/>
 */

/**
 *
 * @author Sebastian Javier Marchano (sebasjm)
 */

import { TranslatedString } from "@gnu-taler/taler-util";
import * as tests from "@gnu-taler/web-util/testing";
import {
  FlexibleForm,
  DefaultForm as TestedComponent,
} from "./DefaultForm.js";

export default {
  title: "Input Choice Horizontal",
};

export namespace Simplest {
  export interface Form {
    comment: string;
  }
}

type TargetObject = {
  comment: string;
}
const initial: TargetObject = {
  comment: "0"
}

const form: FlexibleForm<TargetObject> = {
  design: [{
    title: "this is a simple form" as TranslatedString,
    fields: [{
      type: "choiceHorizontal",
      props: {
        label: "label of the field" as TranslatedString,
        name: "comment",
        choices: [{
          label: "first choice" as TranslatedString,
          value: "1"
        }, {
          label: "second choice" as TranslatedString,
          value: "2"
        }, {
          label: "third choice" as TranslatedString,
          value: "3"
        },],
      },
    }]
  }]
}

export const SimpleComment = tests.createExample(TestedComponent, { initial, form });

==> taler-wallet-v0.13.1.tar.gz: taler-wallet-v0.13.1/packages/web-util/src/forms/InputChoiceHorizontal.stories.tsx <==
/*
 This file is part of GNU Taler
 (C) 2022 Taler Systems S.A.

 GNU Taler is free software; you can redistribute it and/or modify it under the
 terms of the GNU General Public License as published by the Free Software
 Foundation; either version 3, or (at your option) any later version.

 GNU Taler is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

 You should have received a copy of the GNU General Public License along with
 GNU Taler; see the file COPYING.  If not, see <http://www.gnu.org/licenses/>
 */

/**
 *
 * @author Sebastian Javier Marchano (sebasjm)
 */

import { TranslatedString } from "@gnu-taler/taler-util";
import * as tests from "@gnu-taler/web-util/testing";
import {
  FlexibleForm_Deprecated,
  DefaultForm as TestedComponent,
} from "./DefaultForm.js";

export default {
  title: "Input Choice Horizontal",
};

export namespace Simplest {
  export interface Form {
    comment: string;
  }
}

type TargetObject = {
  comment: string;
}
const initial: TargetObject = {
  comment: "0"
}

const form: FlexibleForm_Deprecated<TargetObject> = {
  design: [{
    title: "this is a simple form" as TranslatedString,
    fields: [{
      type: "choiceHorizontal",
      properties: {
        label: "label of the field" as TranslatedString,
        name: "comment",
        choices: [{
          label: "first choice" as TranslatedString,
          value: "1"
        }, {
          label: "second choice" as TranslatedString,
          value: "2"
        }, {
          label: "third choice" as TranslatedString,
          value: "3"
        },],
      },
    }]
  }]
}

export const SimpleComment = tests.createExample(TestedComponent, { initial, form });
